not_same_node

Function not_same_node 

pub fn not_same_node<N, P, UI>(
    from: PinEnd<'_, N, P, UI>,
    to: PinEnd<'_, N, P, UI>,
) -> bool
where N: PartialEq,
Returns true if the two pins live on different nodes, rejecting a node wiring back into itself.